#
# spec file for package cinnamon-session
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cinnamon-session
Version:        6.4.0
Release:        1.3
Summary:        The session manager for the Cinnamon Desktop
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://github.com/linuxmint/cinnamon-session
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-logind.gschema.override
BuildRequires:  docbook
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  tcpd-devel
BuildRequires:  update-desktop-files
BuildRequires:  xmlto
BuildRequires:  xtrans
BuildRequires:  pkgconfig(cinnamon-desktop)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangoxft)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xapp) >= 1.2.0
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xtst)
Requires:       /usr/bin/dbus-launch
Requires:       cinnamon
Requires:       cinnamon-settings-daemon
Requires:       upower >= 0.9.0

%description
This packages contains the session manager for the Cinnamon Desktop.

%prep
%autosetup

%build
%meson \
  -Dfrequent_warnings=true \
  -Dipv6=true    \
  -Dxtrans=true
%meson_build

%install
%meson_install

# We should own this directory.
mkdir -p %{buildroot}%{_datadir}/%{name}/sessions/

# Use systemd-logind for suspend by default.
install -Dpm 0644 %{SOURCE1} \
  %{buildroot}%{_datadir}/glib-2.0/schemas/org.cinnamon.desktop.session.gschema.override

%files
%license COPYING
%doc AUTHORS README README.md
%{_bindir}/%{name}
%{_bindir}/%{name}-quit
%{_libexecdir}/*
%{_datadir}/%{name}/
%{_datadir}/glib-2.0/schemas/org.cinnamon.*
%{_datadir}/icons/hicolor/*/apps/%{name}-properties.*
%{_mandir}/man?/%{name}*.?%{?ext_man}

%changelog
* Sun Jan 12 2025 Marguerite Su <i@marguerite.su>
- update to 6.4.0
  * Refactor/simplify end-session dialog handling to use a native-
    Cinnamon dialog if available
  * autostart: Blacklist nm-applet
* Fri Nov  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Require /usr/bin/dbus-launch instead of dbus-1-x11: the latter is
  supposed to be removed after the move to dbus-broker.
* Tue Aug 13 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 6.2.1:
  * Fix restart and shutdown
- update to 6.2.0:
  * cinnamon-session-quit.py: add missing window icon
  * csm-manager.c: Unset WAYLAND_DISPLAY during shutdown in a wayland
  * main.c: Reset the activation environment at the end of the
  * csm-manager.c: Stop the user dbus-daemon at the end of the session
  * cs-presence.c: Fix CsmPresence idle handling
  * cinnamon-session-quit.py: Set logout window to keep-above and all
  * Remove orphaned include
  * cinnamon-session: make sure wayland sessions get a login shell
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 6.0.4:
  * cinnamon-session-quit.py: Set logout window to keep-above and
    all- workspaces.
  * csm-manager.c: Use the /tmp dir for the dialog server's
    socket file when logged in to a guest account.
  * Packaging: Add missing build-dep on cinnamon-desktop
  * session-quit: Use a unique dialog server address for each
    session.
  * cinnamon-session-quit.py: Try the old fixed server address if
    the session manager doesn't provide the "sm-bus-id" argument.
* Wed Dec 20 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.1:
  * autostart-app: don't try to add child watch to dbus activated
  * util: Unset some environment variables on systemd
* Sat Dec  2 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.0:
  * Fix meson.build deprecations up to 0.56.0
  * wayland: Don't use egg library
  * wayland: Replace cs-idle-monitor with gnome-idle-monitor
  * wayland: Add compatibility
  * wayland: Add DisplayServer phase
  * wayland: Reimplement logout/inhibit dialogs as a separate
    process
  * Clean up and unify logging for session failures
  * More cleanup - leftover includes, unused files
  * Fix build.
  * Don't make a required component failure fatal.
  * On required app failure, log both the app and startup ID.
  * csm-manager: Remove maybe_restart_user_bus.
  * main.c: Don't direct logging to the journal.
  * csm-manager: Terminate the logout dialog at the beginning of
    the session end phase, not the end.
  * cinnamon-session-quit: Set modal.
  * l10n: Update POT
  * cinnamon-session (5.8.1) victoria; urgency=medium
  * Block touchegg from autostarting.
  * cinnamon-session (5.8.0) victoria; urgency=medium
  * main.c: Don't set GTK_OVERLAY_SCROLLING.
  * github workflow: Add optional ssh session.
  * cinnamon-session (5.6.0) vera; urgency=medium
  * Fix .gitignore for builds
  * Accept Desktop Entry Specification v1.5
  * Use github instead of circleci.
  * cinnamon-session (5.4.0) vanessa; urgency=medium
  * Remove gconf code, disable docs, remove doc dependencies.
  * CI: Update targets
* Wed Feb  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(gconf-2.0) BuildRequires: We are already passing
  gconf=false to meson, so this BuildRequires is unused and
  unneeded.
- Drop conditional post(un) handling for no longer supported
  versions of openSUSE.
* Mon Jan 17 2022 andy great <andythe_great@pm.me>
- Update to version 5.2.0.
  * util: Unset LC_* variables (#145)
- Update to version 5.0.1.
  * csm-logout-dialog.c: Grab focus after the widget is shown.
- Fix build fail, fix meson build flag.
* Thu May 27 2021 andy great <andythe_great@pm.me>
- Update to version 5.0.0.
  * Accept Desktop Entry Specification v1.4
  * util: Blacklist some session-specific variables
  * util: Blacklist NOTIFY_SOCKET
  * Fix libexec path for cinnamon-session-check-accelerated-helper
* Tue Dec  8 2020 andy great <andythe_great@pm.me>
- Update to version 4.8.0.
  * implement suspend-then-hibernate
  * respect suspend-then-hibernate setting when suspending from
    menu
* Mon Sep 14 2020 andy great <andythe_great@pm.me>
- Update to version 4.6.2.
  * csm-autostart-app.c: Respect the Path key in desktop files.
* Mon Mar 16 2020 Marguerite Su <i@marguerite.su>
- update version 4.4.1
  * main.c: Add a setting to run the session with
    GDK_SYNCHRONIZE=1, which allows XErrors to be
    backtraced
  * csm-presence.c: Don't start cinnamon-screensaver
    during construction
  * Clean-up remaining dbus-glib references after removal
    in #125
  * csm-systemd.c: Restore old check for logind
- change in 4.4.0
  * csm-system: Check for logind and fall back to consolekit,
    instead of using a gsettings key to determine which to use.
* Mon Sep 30 2019 Marguerite Su <i@marguerite.su>
- drop cinnamon-session-qt-5.7-styleoverride.patch
  * Cinnamon in openSUSE uses Menta/Adwaita by default, which
    perfectly support gtk3. I think there's no need to stay on
    gtk2 theming, and it is really weird for a gtk3 based desktop
    to hard depend on an almostly unmaintained Qt5 library.
  * Users who perfer gtk2 or accidentally install a gtk2 theme
    can set "QT_STYLE_OVERRIDE=gtk2" and "QT_QPA_PLATFORMTHEME=gtk2"
    in /etc/environment (note these global environment variables
    affect all desktops and all users), then install
    libqt5-qtstyleplugins-platformtheme-gtk2
* Fri Sep 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Replace pkgconfig(pangox) with pkgconfig(pango) and
  pkgconfig(pangoxft) BuildRequires: This is what meson checks for.
* Sun Jul 21 2019 Marguerite Su <i@marguerite.su>
- Update to version 4.2.1:
  * Fix wrong parameter type on gdbus logout call
* Mon Jul  1 2019 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 4.2.0:
  * Implement suspend/hibernate via consolekit (#123)
  * csm-manager.c: Don't let inhibitors stop a forced logout.
  * Port to gdbus (#125)
* Fri Mar 15 2019 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 4.0.0:
  * csm-logout-dialog.c: Use the "destructive-action" style classes for (#120)
* Thu Jul  5 2018 sor.alexei@meowr.ru
- Update to version 3.8.2:
  * build: Fix PKGDATADIR define / use only one define.
  * Autostart: Do not let a buggy GSettings condition break the
    session.
* Thu Apr 19 2018 sor.alexei@meowr.ru
- Update to version 3.8.1 (changes since 3.6.1):
  * Switch to Meson.
  * csm-manager: Detect D-Bus user-session at runtime.
  * Add support for elogind.
  * circleci: Add install of updated cinnamon-desktop.
  * circleci: Remove mint18 job.
  * Stop trying to handle Qt integration at all.
  * Quit dialogue: Don't skip taskbar.
  * debian: wrap-and-sort -bst.
  * Fix generation of LOCALE_DIR.
- Remove the no longer needed upower-glib dependency.
- Replace cinnamon-session-fix-qt-themes.patch with
  cinnamon-session-qt-5.7-styleoverride.patch.
* Wed Nov 22 2017 sor.alexei@meowr.ru
- Update to version 3.6.1:
  * configure: Add an option to disable support for D-Bus user
    sessions.
* Sat Oct 28 2017 sor.alexei@meowr.ru
- Update to version 3.6.0:
  * Update environment for dbus and systemd user-session.
  * Add support for "hybrid sleep".
  * Remove unused code.
  * csm-logout-dialog.c: Remove a couple uses of GtkStock.
  * Restart dbus user-session if the last graphical session.
  * Move translations to cinnamon-translations.
* Sun Aug 20 2017 sor.alexei@meowr.ru
- Update to version 3.4.2:
  * Add an issue template.
  * Logout dialogue: Don't grab the keyboard and mouse when opening
    the dialogue.
* Wed Jun 21 2017 sor.alexei@meowr.ru
- Update to version 3.4.1:
  * autostart-blacklist: Add the new gnome settings daemon prefix.
  * csm-manager.c: Listen to the power schema "lock-on-suspend"
    setting instead of the normal screensaver setting of
    "lock when the screensaver starts".
* Tue Jun 13 2017 fvogt@suse.com
- Fix installation on Leap 42.3, it has Qt 5.6 and does not provide
  libqt5-qtstyleplugins-platformtheme-gtk2
* Sun May  7 2017 sor.alexei@meowr.ru
- Update to version 3.4.0:
  * Check stricter for presence of xtrans (with option to disable).
  * Remove aclocal from autogen.sh.
  * Fix redundant redeclarations.
  * manager: Don't wait for all clients to exit before exiting.
* Tue Nov  8 2016 sor.alexei@meowr.ru
- Update to version 3.2.0:
  * Migrate away from gnome-common deprecated vars and macros.
  * Remove an old dialog icon code.
  * gsettings: Stop using g_settings_list_schemas().
  * Use a qt5ct platform theme on Qt 5.7+, qgnomeplatform on 5.6
    and earlier.
  * Use a build time option instead of pkgcheck.
  * Incorporate feedback.
  * Replace the deprecated gtk_icon_info_free() with g_object_unref().
  * main: Fix a heap overflow in dbus-launch wrapping.
  * Add cinnamon-session.pot and makepot.
- Rename and rebase cinnamon-session-qt-5.7-styleoverride.patch to
  cinnamon-session-fix-qt-themes.patch.
* Fri Oct 21 2016 sor.alexei@meowr.ru
- Require libqt5-qtstyleplugins-platformtheme-gtk2 to make sure the
  user actually gets native styling on Qt5 (boo#1002900).
* Sat Oct  8 2016 sor.alexei@meowr.ru
- Add cinnamon-session-qt-5.7-styleoverride.patch: On Qt 5.7+ use
  Gtk2 Platform Theme and don't set QT_STYLE_OVERRIDE to "gtk"
  (boo#1002900).
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 3.0.1:
  * Add support PreDisplayServer phase to fix gnome-keyring ssh
    issue.
  * Add new phase: CSM_MANAGER_PHASE_EARLY_INITIALIZATION, it's
    needed for PRE_DISPLAY_SERVER phase to run.
  * main.c: Add support for disabling gtk overlay scrollbars.
* Mon Apr 25 2016 sor.alexei@meowr.ru
- Update to version 3.0.0:
  * main.c: Remove CLUTTER_BACKEND=x11 (moved to cinnamon main.c).
  * mdm: Fix logic error.
  * Fix a typo in a warning message.
  * Add a provides for x-session-manager.
  * Support new libsystemd (which replaces libsystemd-login).
  * Fix GTK+ regression in csm-inhibit-dialog.
* Wed Mar  9 2016 sor.alexei@meowr.ru
- Update to 2.8.3:
  * mdm: Fix logic error.
  * Fix a typo in a warning message.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 2.8.2:
  * Autostart: Blacklist xfce4-power-manager.
- Change licence to GPL-2.0+ and LGPL-2.1+.
* Sat Oct 31 2015 sor.alexei@meowr.ru
- Update to 2.8.1:
  * csm-logout-dialog.c: Add "automatically" to the msgids of the
  countdown label. This uses the already-translated msgid.
* Tue Oct 20 2015 sor.alexei@meowr.ru
- Update to 2.8.0:
  * Add a gsettings key to enable debug.
  * Reject new XSMP clients earlier in the shutdown path.
  * xsmp: Re-accept clients if session shutdown is cancelled.
  * Avoid to keep zombie clients in the case when a IceError is
    thrown between accept_ice_connection() and
    accept_xsmp_connection().
  * Only wait 1 second max on logout/shutdown.
  * Log time delta in debug mode. Also, don't log dbus calls (they
    don't show much info and they're very numerous).
  * Make Qt5 apps follow the Gtk style.
  * Make the session blacklist entirely configurable.
  * Replace indicator- with indicator-session in session blacklist.
  * Renamed blacklist -> autostart-blacklist.
- Fix dependencies.
- Generate icon cache.
* Tue Aug 11 2015 i@marguerite.su
- use systemd-logind for suspend and etc. by default
* Mon Aug 10 2015 i@marguerite.su
- update version 2.6.3
  * main.c: prevent overlay-scrollbar from loading
  * csm-manager: add a whitelist to override autostart hardcoded list
* Tue Jun  2 2015 stefan@fam-elser.de
- update to version 2.6.2
* Thu Apr 23 2015 stefan@fam-elser.de
- update to version 2.4.3
* Mon Nov 10 2014 i@marguerite.su
- drop zeitgeist Requires. check in minimal X it's no longer needed
- change colord to Recommends. without it cinnamon-settings-daemon
  will trigger a warning but won't prevent you from login
* Mon Nov 10 2014 i@marguerite.su
- update version 2.4.1
  * switched locale path to standard /usr/share/locale
  * re-add session timeout, disable by default
* Wed Nov  5 2014 i@marguerite.su
- update version 2.4.0
- drop patch: cinnamon-session-2.2.0-64bit-portability.patch
  * upstream fixed
* Tue Jul 15 2014 i@marguerite.su
- add nemo to requires
* Mon Jul 14 2014 i@marguerite.su
- update version 2.3.0
  * Remove 'remember open blah blah' in startup programs dialog
* Wed Jul  9 2014 stefan@fam-elser.de
- update version 2.2.2
* Mon May 19 2014 stefan@fam-elser.de
- update version 2.2.1
* Thu Apr 17 2014 i@marguerite.su
- update version 2.2.0
* Mon Nov 25 2013 johann.luce@wanadoo.fr
- update version 2.0.6
  * Fixed wrong socket name for MDM
* Fri Nov  8 2013 johann.luce@wanadoo.fr
- update version 2.0.5
  * Remove upstart files (was breaking Unity)
* Sat Nov  2 2013 i@marguerite.su
- update version 2.0.4
  * fix screensaver command on inhibit dialog
* Fri Nov  1 2013 i@marguerite.su
- add cinnamon-screensaver to requirement
* Wed Oct 30 2013 i@marguerite.su
- add runtime requirement upstream didn't tell
  * NetworkManager-gnome, colord, zeitgeist
* Mon Oct 28 2013 i@marguerite.su
- update version 2.0.3
  * Add consolekit as runtime dep for debian package
  * depend on cinnamon-session-common
* Mon Oct 21 2013 i@marguerite.su
- copypac from home:cyberorg:cinnamon
- cleanup work
- add glib schemas macros
- remove --enable-systemd because by default it's auto and needs
  systemd >= 183, while openSUSE 12.2 only has 44
* Mon Oct 21 2013 stefan@fam-elser.de
- Added systemd as requirement
* Sun Oct 20 2013 stefan@fam-elser.de
- Updated spec file to enable systemd
* Thu Oct 10 2013 stefan@fam-elser.de
- Updated to version 2.0.1
* Wed Oct  9 2013 stefan@fam-elser.de
- Updated to version 2.0.0
* Wed Oct  2 2013 stefan@fam-elser.de
- Initial release with version 1.9.2
